#
# ficus_getopt.pl
# Copyright (C) 1991-5 by John Heidemann <johnh@isi.edu>
# $Id: ficus_getopt.pl,v 1.4 1995/11/22 22:10:36 johnh Exp $
#
# This program is distributed under terms of the GNU general
# public license, version 2.  See the file COPYING
# in $dblib for details.
#
#
# Taken from:
#
# getoptk.pl -- getopt-like processing for Perl scripts
#	Brian Katzung  12 June 1993
#	<katzung@katsun.chi.il.us>
#
# usage:	while (($option = &getopt("ab:")) ne '')
#
# The next option is returned with each call until there are no more
# (indicated by the empty string).  If the option appears in the list
# supplied as argument, $optarg is set to the option value (the
# remaining characters or the next word).
#
# For more detailed usage, look at getopt(3).
#

$ficus_getopt_next = '';
$opterr = 1;

sub ficus_getopt {
    local($[) = 0;
    local($withArgs) = $_[0];
    local($next);
    local($option, $i);

    #
    # Fetch the next option string if necessary.
    #
    if (($next = $ficus_getopt_next) eq '') {
	#
	# Stop if there are no more arguments, if we see '--',
	# or if the next argument doesn't look like an option
	# string.
	#
	return ''
	    if (($#ARGV < 0) || ($ARGV[0] eq '-') || ($ARGV[0] !~ /^-/));
	if ($ARGV[0] eq '--') {
	    shift(@ARGV);
	    return '';
	}
	
	#
	# Grab the next argument and remove it from @ARGV.
	#
	$next = substr(shift(@ARGV), 1);
    };

    #
    # Peel off the next option.
    #
    $option = substr($next, 0, 1);
    $next = substr($next, 1);

    $i = index($withArgs, $option);
    if ($i == -1) {
	#
	# Unknown option.
	#
	die("unknown option '$option'") if ($opterr);
	# # put the argument back on ARGV
	# unshift (@ARGV, "-$option$next");
	return '?';   # this isn't completely getopt compliant
    };
    if (substr($withArgs, $i+1, 1) eq ':') {
	#
	# The option takes an argument.  Take the argument
	# from the remainder of the option string, or use
	# the next argument if the option string is empty.
	#
	if ($next ne '') {
	    $optarg = $next;
	    $next = '';
	} else {
	    $optarg = shift(@ARGV);
	};
    };

    #
    # Save the remainder of the option string and return
    # the current option.
    #
    $ficus_getopt_next = $next;
    return $option;
}

#
# ficus_getopt_abort:
# Abort current option parsing.
# Place any remaining options back on @ARGV.
#
sub ficus_getopt_abort {
    unshift(@ARGV, "-$ficus_getopt_next") if ($ficus_getopt_next ne '');
};

1;
